"""
QARDL Package Version Information
"""

__version__ = "1.0.4"
__author__ = "Dr. Merwan Roudane"
__email__ = "merwanroudane920@gmail.com"
__description__ = "Quantile Autoregressive Distributed Lag (QARDL) Models - Cho, Kim & Shin (2015)"
__url__ = "https://github.com/merwanroudane/qardl"

# Version history
__version_info__ = {
    "1.0.4": "Bug fixes: test_long_run_parameters, ECM broadcasting, lag selection, rolling.estimate",
    "1.0.2": "Import fixes for utils and visualization",
    "1.0.1": "Critical fix for X_effective ordering",
    "1.0.0": "Initial release"
}
